==> jc-1.4.0.tar.gz: javax/swing/text/LayeredHighlighter__24LayerPainter.h <==
// public abstract class javax.swing.text.LayeredHighlighter$LayerPainter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ee9c929c384f62e3 javax_swing_text_LayeredHighlighter__24LayerPainter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_LayeredHighlighter__24LayerPainter_H_
#define _JC_javax_swing_text_LayeredHighlighter__24LayerPainter_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs;
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs;
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$refs	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$refs;
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$nonrefs	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$nonrefs;
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object;

typedef const struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods;
typedef const struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtable	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtable;
typedef const struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype;

// Constructors
extern void _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$method$paintLayer$5ec0c7bc1ade4ddd(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$method_info$paintLayer$5ec0c7bc1ade4ddd;

// Virtual methods structure
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods {
	struct _jc_object	*(*paintLayer$5ec0c7bc1ade4ddd)(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *);
};

// Vtable
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods	javax_swing_text_LayeredHighlighter__24LayerPainter;
};

// Vtype
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$refs {
    _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs	javax_swing_text_LayeredHighlighter__24LayerPainter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs	javax_swing_text_LayeredHighlighter__24LayerPainter;
};

// Object instance structure
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object {
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype	*vtype;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_LayeredHighlighter__24LayerPainter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$class_object;

#endif	/* _JC_javax_swing_text_LayeredHighlighter__24LayerPainter_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/LayeredHighlighter__24LayerPainter.h <==
// public abstract class javax.swing.text.LayeredHighlighter$LayerPainter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ee9c929c384f62e3 javax_swing_text_LayeredHighlighter__24LayerPainter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_LayeredHighlighter__24LayerPainter_H_
#define _JC_javax_swing_text_LayeredHighlighter__24LayerPainter_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_View$object;

// Typedefs
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs;
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs;
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$refs	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$refs;
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$nonrefs	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$nonrefs;
typedef struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object;

typedef const struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods;
typedef const struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtable	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtable;
typedef const struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype;

// Constructors
extern void _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$method$paintLayer$5ec0c7bc1ade4ddd(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$method_info$paintLayer$5ec0c7bc1ade4ddd;

// Virtual methods structure
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods {
	struct _jc_object	*(*paintLayer$5ec0c7bc1ade4ddd)(_jc_env *, struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object *, struct _jc_java_awt_Graphics$object *, jint, jint, struct _jc_object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_javax_swing_text_View$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vmethods	javax_swing_text_LayeredHighlighter__24LayerPainter;
};

// Vtype
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$refs {
    _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_refs	javax_swing_text_LayeredHighlighter__24LayerPainter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$sub_nonrefs	javax_swing_text_LayeredHighlighter__24LayerPainter;
};

// Object instance structure
struct _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$object {
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype	*vtype;
	_jc_javax_swing_text_LayeredHighlighter__24LayerPainter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$vtype _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_LayeredHighlighter__24LayerPainter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_LayeredHighlighter__24LayerPainter$class_object;

#endif	/* _JC_javax_swing_text_LayeredHighlighter__24LayerPainter_H_ */
